@@ -1,6 +1,6 @@
 package Pcore::API::Map::Field::Id;
 
-use Pcore qw[-class];
+use Pcore -class;
 
 extends qw[Pcore::API::Map::Field::Int];
 
@@ -25,8 +25,6 @@ around ext_model_field => sub {
     return;
 };
 
-no Pcore;
-
 1;
 __END__
 =pod
