@@ -1,6 +1,6 @@
 package Pcore::API::Map::Field::Num;
 
-use Pcore qw[-class];
+use Pcore -class;
 
 extends qw[Pcore::API::Map::Field];
 
@@ -18,8 +18,6 @@ around ext_model_field => sub {
     return $field;
 };
 
-no Pcore;
-
 sub writer {
     my $self = shift;
     my $val  = shift;
